@@ -6,7 +6,7 @@
 typedef struct
 {
     char const *d_name;
-    void (*d_action)();
+    void (*d_action)(void);
 }
 Builtin;
 
@@ -15,6 +15,6 @@ Builtin    *builtin_copy(Builtin const *builtin);
 void        builtin_insert(HashMap *symtab, Builtin *builtin);
 void        builtin_call(Builtin *builtin);
 char const *builtin_name(Builtin const *builtin);
-void      (*builtin_setAction(Builtin *builtin, void (*)()))();
+void      (*builtin_setAction(Builtin *builtin, void (*)(void)))(void);
 
 #endif
