@@ -14,18 +14,17 @@ convenience sake the header stdlib.h
     char        *new_str(char const *str);  is in root.h
 */
 
-void        *new_memory(unsigned nElements, unsigned sizeofElement);
-void        *new_calloc(unsigned nElements, unsigned sizeofElement);
+void        *new_memory(size_t   nElements, size_t   sizeofElement);
+void        *new_calloc(size_t   nElements, size_t   sizeofElement);
 int         *new_int(int value);
 long        *new_long(long value);
-void        *new_memory(unsigned nelements, unsigned sizeofElement);
-unsigned    *new_unsigned(unsigned value);
+void        *new_memory(size_t   nelements, size_t   sizeofElement);
 
                         /* `memory' must be the address of a pointer.
                             E.g., char *str -> new_size(&str, ...
                         */
-void        *new_size(void *memory, unsigned new_n, unsigned old_n,
-                                                unsigned sizeofElement);
+void        *new_size(void *memory, size_t   new_n, size_t   old_n,
+                                                size_t   sizeofElement);
 void        *new_voidp(void *value);            /* returns pointer to value */
 
 #endif
