@@ -1,9 +1,9 @@
 #include "new.ih"
 
-void  *new_size(void *memory, unsigned new, unsigned old,
-                                            unsigned sizeofElement)
+void  *new_size(register void *memory, size_t new, size_t old,
+                                            size_t sizeofElement)
 {
-    void *ret =
+    register void *ret =
         memcpy
         (
             new_calloc(new, sizeofElement),
