@@ -1,6 +1,6 @@
 #include "stack.ih"
 
-unsigned stack_size(Stack const *sp)
+size_t stack_size(Stack const *sp)
 {
     return sp->d_n;
 }
