@@ -2,5 +2,5 @@
 
 void string_construct(String *s, char const *str)
 {
-    s_init(s, str);
+    s_init(s, str ? str : s_empty);
 }
