@@ -9,9 +9,9 @@ void handle_html_newfile(long offset, HashItem *item)
         fclose(global.d_out);
                                             /* construct the new output     */
                                             /* file name                    */
-        string_format(&global.d_outName, "%s%02d.%s",
+        string_format(&global.d_outName, "%s%02u.%s",
                             global.d_noext,
-                            global.d_fileNr,
+                            (unsigned)global.d_fileNr,
                             global.d_ext);
 
                                             /* and open it                  */
@@ -32,5 +32,5 @@ void handle_html_newfile(long offset, HashItem *item)
             hashmap_textOf(&global.d_symbol, "bodytagopt")
     );
 
-    html_chapterlinks(global.d_fileNr);    /* and the chapterlinks         */
+    html_chapterlinks((int)global.d_fileNr);    /* and the chapterlinks     */
 }
